@@ -775,7 +775,7 @@ Valid real attributes: ['clear', 'clone', 'env_prefix', 'file_prefix', 'from_dat
             def arbitrary_types_work_too(self):
                 os.environ["INVOKE_FOO"] = "whatever"
 
-                class Meh(object):
+                class Meh:
                     def __init__(self, thing=None):
                         pass
 
@@ -1039,24 +1039,6 @@ Valid real attributes: ['clear', 'clone', 'env_prefix', 'file_prefix', 'from_dat
                 c2 = c.clone()
                 assert c2.meh == "okay"
 
-            def raises_TypeError_if_value_is_not_Config_subclass(self):
-                try:
-                    Config().clone(into=17)
-                except TypeError:
-                    pass
-                else:
-                    assert False, "Non-class obj did not raise TypeError!"
-
-                class Foo(object):
-                    pass
-
-                try:
-                    Config().clone(into=Foo)
-                except TypeError:
-                    pass
-                else:
-                    assert False, "Non-subclass did not raise TypeError!"
-
             def resulting_clones_are_typed_as_new_class(self):
                 class MyConfig(Config):
                     pass
